import 'server-only';
import { getVariableValue } from './getVariableValue';
import { initialize, validateSDKKey } from './initialize';
import { getUserAgent } from './userAgent';
import { getAllVariables } from './getAllVariables';
import { getAllFeatures } from './allFeatures';
// allow return type inference
// eslint-disable-next-line @typescript-eslint/explicit-module-boundary-types
export const setupDevCycle = ({ serverSDKKey, clientSDKKey, userGetter, options, }) => {
    validateSDKKey(serverSDKKey, 'server');
    validateSDKKey(clientSDKKey, 'client');
    const _getVariableValue = async (key, defaultValue) => {
        await initialize(serverSDKKey, userGetter, options);
        return getVariableValue(key, defaultValue);
    };
    const _getAllVariables = async () => {
        await initialize(serverSDKKey, userGetter, options);
        return getAllVariables();
    };
    const _getAllFeatures = async () => {
        await initialize(serverSDKKey, userGetter, options);
        return getAllFeatures();
    };
    const _getClientContext = () => {
        var _a;
        const serverDataPromise = initialize(serverSDKKey, userGetter, options);
        const { enableStreaming, enableObfuscation, ...otherOptions } = options;
        const { disableAutomaticEventLogging, disableCustomEventLogging, disableRealtimeUpdates, apiProxyURL, eventFlushIntervalMS, flushEventQueueSize, } = otherOptions;
        const clientOptions = {
            disableAutomaticEventLogging,
            disableCustomEventLogging,
            disableRealtimeUpdates,
            apiProxyURL,
            eventFlushIntervalMS,
            flushEventQueueSize,
            enableObfuscation,
        };
        return {
            serverDataPromise,
            options: clientOptions,
            clientSDKKey: clientSDKKey,
            enableStreaming: (_a = options === null || options === void 0 ? void 0 : options.enableStreaming) !== null && _a !== void 0 ? _a : false,
            userAgent: getUserAgent(options),
        };
    };
    return {
        getVariableValue: _getVariableValue,
        getAllVariables: _getAllVariables,
        getAllFeatures: _getAllFeatures,
        getClientContext: _getClientContext,
    };
};
//# sourceMappingURL=setupDevCycle.js.map